@@ -5,15 +5,18 @@ and deploying/running your package. Simple database integration and State cachin
 objects.
 """
 
-__name__ = "Feathery"
-__version__ = "v0.0.1"
+__name__ = "feathery-py"
+__version__ = "0.0.4"
 __author__ = "NotOddity"
+__url__ = "https://github.com/NotOddity/feathery"
+__description__ = "No description yet"
 
 # local package imports
 from . import commands
 from . import events
 from . import resources
 from . import types
+from . import exceptions
 
 # local module imports
 from .async_core import *
